==> org.eclipse.m2e.archetype.common.source_1.18.1.20211011-2139.jar: org/apache/maven/archetype/downloader/Downloader.java <==
package org.apache.maven.archetype.downloader;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.artifact.repository.ArtifactRepository;

import java.io.File;
import java.util.List;

/**
 * @author Jason van Zyl
 */
public interface Downloader
{
    String ROLE = Downloader.class.getName();

    File download( String groupId, String artifactId, String version, ArtifactRepository archetypeRepository,
                   ArtifactRepository localRepository, List<ArtifactRepository> remoteRepositories )
        throws DownloadException, DownloadNotFoundException;

    File downloadOld( String groupId, String artifactId, String version, ArtifactRepository archetypeRepository,
                      ArtifactRepository localRepository, List<ArtifactRepository> remoteRepositories )
        throws DownloadException, DownloadNotFoundException;
}

==> org.eclipse.m2e.archetype.common.source_3.2.104.jar: org/apache/maven/archetype/downloader/Downloader.java <==
package org.apache.maven.archetype.downloader;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.artifact.repository.ArtifactRepository;
import org.apache.maven.project.ProjectBuildingRequest;

import java.io.File;
import java.util.List;

/**
 * @author Jason van Zyl
 */
public interface Downloader
{
    File download( String groupId, String artifactId, String version, ArtifactRepository archetypeRepository,
                   ArtifactRepository localRepository, List<ArtifactRepository> remoteRepositories,
                   ProjectBuildingRequest buildingRequest )
        throws DownloadException, DownloadNotFoundException;

    File downloadOld( String groupId, String artifactId, String version, ArtifactRepository archetypeRepository,
                      ArtifactRepository localRepository, List<ArtifactRepository> remoteRepositories,
                      ProjectBuildingRequest buildingRequest )
        throws DownloadException, DownloadNotFoundException;
}
